@@ -1,7 +1,4 @@
-try:
-    from django.conf.urls import patterns, url, include
-except ImportError:  # For backwards compatibility with Django <=1.3
-    from django.conf.urls.defaults import patterns, url, include
+from django.conf.urls import patterns, url, include
 from django.contrib import admin
 
 import backbone
